@@ -58,11 +58,6 @@ class ClSetupVideoAction(Action):
          'method': 'Install.checkVideoDriver()',
          'condition': lambda: isPkgInstalled('xorg-server')
          },
-        {'name': 'setup_opengl',
-         'message': __("Configuring OpenGL"),
-         'method': 'Install.setupOpenGL()',
-         'condition': lambda: isPkgInstalled('xorg-server')
-         },
         {'name': 'setupvideo',
          'condition': lambda Get: Get('cl_setup') == 'video'
          },
